##################################################################################
## This script will generate the estimated missing ratio of Type I for CT and MA
## 1) Two different incubation periods are used, T=6 and T=7
## 2) Plots can be generated by data collected at 04/22/2020 or 08/31/2020
##
## Version history: 
## Ver 1.0		By Donghui Yan 		04/22/2020
## Ver 1.1		By Donghui Yan		09/01/2020
##			Code modified to allow the choice of 04/22 or 08/31 data 
################################################################################## 
##
##Uncomment to pick one version of data
##whichD<-c("0422");
whichD<-c("0831");
##To point to the correct data directory
dirPtr<-paste("Data_",whichD,"/",sep="");

##To load the CT data
Abbr<-c("CT");
x<-read.table(paste(dirPtr,Abbr,".Data",sep=""),sep="");
x<-x[-nrow(x),];

T<-6;	##Length of incubation period
r1<-x[(T+1):nrow(x),2]/x[1:(nrow(x)-T),2]-1;
L<-length(r1); r1<-r1[-L];
T<-7;
r3<-x[(T+1):nrow(x),2]/x[1:(nrow(x)-T),2]-1;

##To load the MA data
Abbr<-c("MA");
x<-read.table(paste(dirPtr,Abbr,".Data",sep=""),sep="");
T<-6;
r2<-x[(T+1):nrow(x),2]/x[1:(nrow(x)-T),2]-1;
L<-length(r2); r2<-r2[-L];
T<-7;
r4<-x[(T+1):nrow(x),2]/x[1:(nrow(x)-T),2]-1;

##To plot the type I ratio through time for CT and MA 
postscript(file=paste("Type1_CTMA67_",whichD,".eps", sep=""),
		height=5.2, width=4.5);

l1<-length(r1); l2<-length(r2); 
n<-min(l1,l2)-1; ##To justify to the data with a later starting date

par(font=2);
plot(1:n,r1[(l1-n+1):l1],pch=17,col="blue",
		ylim=c(0,10),
		xlab=paste("Days since Mar 8, 2020"), 
		ylab="Estimated type I ratio");
points(1:n, r3[(l1-n+1):l1], pch=24, col="blue");
points(1:n, r2[(l2-n+1):l2], pch=15, col="red");
points(1:n, r4[(l2-n+1):l2], pch=22, col="red");

legend("topright", legend=c("CT6","CT7","MA6","MA7"), 
		pch=c(17,24,15,22),
		col=c("blue","blue","red","red"));

dev.off();