##################################################################################
## This script will plot the estimated infection ratio for all 50 US states by 
## heatmap on the US map. The infection ratio for individual states are generated
## for two different dates, 04/22/2020 and 08/31/2020, respectively.
##
## Version history: 
## Ver 1.0		By Donghui Yan 		04/22/2020
## Ver 1.1		By Donghui Yan		09/01/2020
##			Code modified to allow the choice of 04/22 or 08/31 data 
################################################################################## 
##
##Uncomment to pick one version of data
whichD<-c("0422");
##whichD<-c("0831");
##To point to the correct data directory
dirPtr<-paste("Data_",whichD,"/",sep="");

library(maps);
library(maptools);
library(sp);

##First read input data and add a column with states name
##Or use the hard-coded numbers
if(F){
x<-read.table(paste(dirPtr,"allStates",whichD,".Data",sep=""),sep=",");
tmp<-sort(as.character(x[,1]),decreasing=FALSE,index.return=TRUE);
x<-x[tmp$ix,];
}

##Estimated Infection ratio for 50 US states
##As of 04/22/2020
if(whichD=="0422")
{ txt <- "AL  AZ AR    CA  CO  CT  DE  FL  GA  ID  IL  IN  IA KS KY LA ME MD MA MI MN MS MO MT NE NV NH NJ NM NY NC ND OH OK OR PA RI SC SD TN TX UT VT VA WA WV WI WY

0.244 0.160 0.186 0.206 0.407 1.22 0.801 0.274 0.444 0.201 0.638 0.418 0.320 0.179 0.176 1.04 0.138 0.570 1.31 0.705 0.114 0.382 0.206 0.079 0.246 0.279 0.263 2.11 0.232 2.61 0.155 0.244 0.323 0.158 0.101 0.618 1.15 0.199 0.507 0.246 0.160 0.234 0.257 0.263 0.326 0.121 0.180 0.115";
}else ##As of 08/31/2020
{ txt <- "AL  AZ AR    CA  CO  CT  DE  FL  GA  ID  IL  IN  IA KS KY LA ME MD MA MI MN MS MO MT NE NV NH NJ NM NY NC ND OH OK OR PA RI SC SD TN TX UT VT VA WA WV WI WY

3.600 3.834 2.824 2.484 1.377 2.085 2.493 3.973 3.531 2.463 2.602 1.970 2.792 2.111 1.508 4.472 0.471 2.494 2.582 1.430 1.937 3.890 1.924 0.968 2.461 3.109 0.744 3.016 1.695 3.140 2.210 2.208 1.470 2.082 0.871 1.465 2.915 3.201 2.097 3.149 2.915 2.240 0.362 1.960 1.346 0.808 1.811 0.950";
}

abbvs<-c("AL",  "AZ", "AR",    "CA",  "CO",  "CT",  "DE",  "DC","FL",  "GA",  "ID",  "IL",  "IN",  "IA", "KS", "KY", "LA", "ME", "MD", "MA", "MI", "MN", "MS", "MO", "MT", "NE", "NV", "NH", "NJ", "NM", "NY", "NC", "ND", "OH", "OK", "OR", "PA", "RI", "SC", "SD", "TN", "TX", "UT", "VT", "VA", "WA", "WV", "WI", "WY");

##Output as .eps figure
postscript(file=paste("infRatioUS",whichD,".eps",sep=""), height=5.0, width=7.5);

dat <- stack(read.table(text = txt,  header = TRUE));
names(dat)[2] <-'state.abb';
dat$states <- tolower(state.name[match(dat$state.abb,  state.abb)]);

##Then load the map and convert to a SpatialPolygons
mapUSA <- map('state',  fill = TRUE,  plot = FALSE);
nms <- sapply(strsplit(mapUSA$names,  ':'),  function(x)x[1])

USApolygons <- map2SpatialPolygons(mapUSA,  IDs = nms,  CRS('+proj=longlat'))


##And now you add the information from your data:
idx <- match(unique(nms),  dat$states)
dat2 <- data.frame(value = -dat$value[idx], state = unique(nms),
				abbv=abbvs);
row.names(dat2) <- unique(nms);
USAsp <- SpatialPolygonsDataFrame(USApolygons,  data = dat2);

if(whichD=="0422")
{ seqs<-seq(-3.0,0,by=0.5);
  labels<-c("3.0","2.5","2.0","1.5","1.0","0.5","0.0");
}else { seqs<-seq(-4.0,0,by=0.5);
  labels<-c("4.0","3.5","3.0","2.5","2.0","1.5","1.0","0.5","0.0");
}

if(whichD=="0422") {dateY<-c("(04/20/2020)");} else{ dateY<-c("(08/31/2020)");}

spplot(USAsp['value'], 
	xlab=paste("Percent of population infected by state ",dateY,sep=""),		
	colorkey = list(space = "right",
				at=seqs,
				labels=labels,
				height = 1.0),
	sp.layout=list("sp.text",coordinates(USAsp['value']),abbvs,cex=0.8));
dev.off();