##################################################################################
## This script will generate the trend of estimated infection ratio and estimated
## number of infected cases for 6 heavily hit states NY, NJ, CT, MA, RI and LA. 
## Plots can be generated for 04/22/2020 and 08/31/2020.
##
## Version history: 
## Ver 1.0		By Donghui Yan 		04/22/2020
## Ver 1.1		By Donghui Yan		09/01/2020
##			Code modified to allow the choice of 04/22 or 08/31 data 
################################################################################## 
##
##Uncomment to pick one version of data
##whichD<-c("0422");
whichD<-c("0831");
##To point to the correct data directory
dirPtr<-paste("Data_",whichD,"/",sep="");

##Length of incubation period
T<-7;

##Ratio of type II cases
if(whichD=="0422") {p2<-0.873894;} else{p2<-0.3354;}

Abbrs<-c("NY","NJ","CT","MA","RI","LA");
##To load the population for the 6 states
z<-read.table("US_POP.Data", sep="", header=TRUE);

###############################################################
## To calculate the infection ratio series given a case number 
## series
###############################################################
infRatio<-function(Abbr, xc, pop)
{
n<-length(xc);

r1<-x[(T+1):n,2]/x[1:(n-T),2]-1;
iRatio<-x[1:(n-T),2]*(1+r1+p2)/pop;
return(iRatio);
}


infM<-matrix(0,300,length(Abbrs));
pops<-matrix(0,1,length(Abbrs));
mm<-500;
for(i in 1:length(Abbrs))
{
Abbr<-Abbrs[i];
x<-read.table(paste(dirPtr,Abbr,".Data",sep=""),sep="");

idx<-match(Abbr,z[,1]);
pop<-z[idx,2];

iRatio.vec<-infRatio(Abbr, x[,2], pop);
m<-length(iRatio.vec);
if(m<mm) {mm<-m;}
infM[m:1,i]<-iRatio.vec;
pops[i]<-pop;
}
infM<-infM*100;

#########################################################################
## To plot the infection ratio for 6 states
#########################################################################
postscript(file=paste("infRatioStates6-",whichD,".eps",sep=""), 
		height=5.4, width=5.8);
par(font=2);

##Range of display in the plot
if(whichD=="0422") {ylims<-c(0,3.0);} else{ylims<-c(0,4.5);}

plot(1:mm,infM[mm:1,1],pch=15,col="red",ylim=ylims,
	##xlab=paste("Days since Mar 9, 2020"), 
	xlab="",type="b", xaxt='n',
	ylab="Estimated infection ratio (%)");

if(whichD=="0422"){xat<-c(0,10,20,30,40);
axis(side=1,at=xat,labels=c("03/08","03/18","03/28","04/07","04/17"));
} else {
xat<-c(0,50,100,150);
axis(side=1,at=xat,labels=c("03/09","04/28","06/17","08/06"));
}
points(1:mm, infM[mm:1,2], pch=2, col="forestgreen",type="b");
points(1:mm, infM[mm:1,3], pch=25, col="blue");
points(1:mm, infM[mm:1,4], pch=22, col="black");
points(1:mm, infM[mm:1,5], pch=17, col="deepskyblue2");
points(1:mm, infM[mm:1,6], pch=18, col="blue");

legend("topleft", legend=c("NY","NJ","CT","MA","RI","LA"), 
			pch=c(15,2,25,22,17,18),
			col=c("red","forestgreen","blue","black","deepskyblue2","blue"));
dev.off();


#########################################################################
## To plot the number of cases
#########################################################################
postscript(file=paste("infCasesStates6-",whichD,".eps",sep=""),
		height=5.0, width=5.8);
K<-100000;
par(font=2);
plot(1:mm,infM[mm:1,1]*pops[1]/K,pch=15,col="red",##ylim=c(1.0,6.0),
	xlab="",type="b",
	xaxt='n',
	ylab="Estimated number of cases (k)");

if(whichD=="0422"){xat<-c(0,10,20,30,40);
axis(side=1,at=xat,labels=c("03/08","03/18","03/28","04/07","04/17"));
} else {
xat<-c(0,50,100,150);
axis(side=1,at=xat,labels=c("03/08","04/27","06/16","08/05"));
}
points(1:mm, infM[mm:1,2]*pops[2]/K, pch=2, col="forestgreen",type="b");
points(1:mm, infM[mm:1,3]*pops[3]/K, pch=25, col="blue");
points(1:mm, infM[mm:1,4]*pops[4]/K, pch=22, col="black");
points(1:mm, infM[mm:1,5]*pops[5]/K, pch=17, col="deepskyblue2");
points(1:mm, infM[mm:1,6]*pops[6]/K, pch=18, col="blue");

legend("topleft", legend=c("NY","NJ","CT","MA","RI","LA"), 
			pch=c(15,2,25,22,17,18),
			col=c("red","forestgreen","blue","black","deepskyblue2","blue"));


dev.off();