##################################################################################
## This script will generate the estimated missing ratio of Type I for all 50 US
## states with the incubation period T=7. Available for two different dates,
## 04/22/2020 and 08/31/2020, respectively.
##
## Version history: 
## Ver 1.0		By Donghui Yan 		04/22/2020
## Ver 1.1		By Donghui Yan		09/01/2020
##			Code modified to allow the choice of 04/22 or 08/31 data 
################################################################################## 
##
##Uncomment to pick one version of data
##whichD<-c("0422");
whichD<-c("0831");
##To point to the correct data directory
dirPtr<-paste("Data_",whichD,"/",sep="");

##Length of incubation period
T<-7;

z<-read.table("US_POP.Data", sep="", header=TRUE);
Abbrs<-c("NY","NJ","CA","TX","AZ","FL","CT","MA","RI","PA",
		"OH","IL","MD","WA","VA","WV","NH","ME","VT","UT",
		"CO", "MT", "MI", "LA","AK","AR","AL","DE","GA","HI",
		"IA","ID","IN","KS","KY","MN","MO","MS","NC","ND",
		"NE","NM","NV","OK","OR","SC","SD","TN","WI","WY");

##Ratio of type II cases
if(whichD=="0422") { p2<-0.873894;} else{ p2<-0.3354;} 
uRatio2<-p2;

byState<-matrix(0,length(Abbrs),6);
for(i in 1:length(Abbrs))
{
Abbr<-Abbrs[i];
x<-read.table(paste(dirPtr,Abbr,".Data",sep=""),sep="");
r1<-x[(T+1):nrow(x),2]/x[1:(nrow(x)-T),2]-1;
idx<-match(Abbr,as.character(z[,1]));
pop<-z[idx,2];

##Ratio of type I
uRatio1<-r1[length(r1)];
iRatioC12<-x[nrow(x),2]*(1+uRatio1+uRatio2)/pop;
reported<-x[nrow(x),2];

line<-c(Abbr, pop, uRatio1, uRatio2, iRatioC12, reported);
byState[i,]<-line;
}
write.table(byState,file=paste(dirPtr,"allStates",whichD,".Data",sep=""),
			row.name=FALSE, col.name=FALSE, sep=",");

iRatioAg2<-sum(as.numeric(byState[,2]) * as.numeric(byState[,5]))/sum(as.numeric(byState[,2]));


###################################################################################
## Scatter plot of type I ratio by states
###################################################################################
y<-as.numeric(byState[,3]);
colors<-c("royalblue1","lightcoral","palegoldenrod","green","orange","cyan","brown","yellow",
		"chartreuse1","deepskyblue1");

postscript(file=paste("typeI50_",whichD,".eps",sep=""), height=5.7, width=7.0);

if(whichD=="0422") { ylims<-c(min(y)-0.05, max(y)+0.04);} else {ylims<-c(min(y)-0.01, max(y)+0.01);}

plot(1:50, y, col="blue", pch=17,ylab="Estimated type I ratio",xlab="",
		ylim=ylims, xaxt="n",cex.lab=1.2);

##Manual adjustment of text positions to avoid plot being over-crowded
if(whichD=="0422")
{
y[3]<-y[3]+0.055; ##CA
y[5]<-y[5]+0.055; ##AZ
y[15]<-y[15]+0.055; ##VA
y[20]<-y[20]+0.055; ##UT
y[22]<-y[22]+0.055; ##MT
y[29]<-y[29]+0.055; ##GA
y[35]<-y[35]+0.055; ##SD
y[36]<-y[36]+0.055; ##MN
y[39]<-y[39]+0.055; ##OK
y[41]<-y[41]+0.055; ##NE
y[43]<-y[43]+0.055; ##NV
y[48]<-y[48]+0.055; ##TN
text(x=(1:50)+0.7, y=y-0.027, labels=byState[,1],cex=0.8);
} else{ ##As of 08/31/2020
h<-0.017;
y[2]<-y[2]+h; ##NJ
y[4]<-y[4]+h; ##TX
y[6]<-y[6]+h; ##FL
y[7]<-y[7]+h; ##CT
y[10]<-y[10]+h; ##PA
y[11]<-y[11]+h; ##OH
y[18]<-y[18]+h; ##ME
y[20]<-y[20]+h; ##UT
y[27]<-y[27]+h; ##AL
y[33]<-y[33]+h; ##IN
y[34]<-y[34]+h; ##KS
y[37]<-y[37]+h; ##MO
y[39]<-y[39]+h; ##NC
y[45]<-y[45]+h; ##OR
y[48]<-y[48]+h; ##TN
y[50]<-y[50]+h; ##WY
xx<-1:50;
xx[1]<-xx[1]-1; ##NY
xx[3]<-xx[3]-1; ##CA
xx[7]<-xx[7]-1; ##CT
xx[8]<-xx[8]-0.3; ##MA
xx[9]<-xx[9]+0.5; ##RI
xx[49]<-xx[49]-1; ##WI
text(x=xx+0.6, y=y-0.008, labels=byState[,1],cex=0.8);
}
dev.off();


