##################################################################################
## This script will generate the estimated missing ratio of Type I for CT and MA
## 1) Two different incubation periods are used, T=6 and T=7
## 2) Plots can be generated by data collected at 04/22/2020 or 08/31/2020
##
## Version history: 
## Ver 1.0		By Donghui Yan 		04/22/2020
## Ver 1.1		By Donghui Yan		09/01/2020
##			Code modified to allow the choice of 04/22 or 08/31 data 
################################################################################## 
##
##Uncomment to pick one version of data
##whichD<-c("0422");
whichD<-c("0831");
##To point to the correct data directory
dirPtr<-paste("Data_",whichD,"/",sep="");

Abbr<-c("US");
x<-read.table(paste(dirPtr,Abbr,".Data",sep=""),sep="");
x<-x[-nrow(x),];
##Length of incubation period
T<-6;
r1<-x[(T+1):nrow(x),2]/x[1:(nrow(x)-T),2]-1;
L<-length(r1); r1<-r1[-L];
T<-7;
r2<-x[(T+1):nrow(x),2]/x[1:(nrow(x)-T),2]-1;

##To reposition in time series in order to match other plots
idx<-match("2020-03-01",as.character(x[,1]));
l1<-length(r1); l2<-length(r2); 
n<-l1-idx+1;

postscript(file=paste("type1US67_",whichD,".eps",sep=""),height=5.2, width=4.5);
par(font=2);
plot(1:n, r1[(l1-n+1):l1],pch=17,col="blue",
		ylim=c(0,max(r1[(l1-n+1):l1],r2[(l2-n+1):l2])+1),
		xlab="Days since Mar 8, 2020", ylab="Estimated type I ratio");
points(1:n, r2[(l2-n+1):l2], pch=15, col="red");
for(i in l2:(l2-n+1))
{
	lines(c(i-l2+n,i-l2+n),c(r2[i],r1[i]),col="blue");
}

legend("topright", legend=c("US6","US7"),
				pch=c(17,15), col=c("blue","red"));

dev.off();
